import type { Constructor } from '../../utils/mixins';
import type { DidRegistrar, DidResolver } from './domain';
import { KeyDidRegistrar, SovDidRegistrar, PeerDidRegistrar, PeerDidResolver, SovDidResolver } from './methods';
/**
 * DidsModuleConfigOptions defines the interface for the options of the DidsModuleConfig class.
 * This can contain optional parameters that have default values in the config class itself.
 */
export interface DidsModuleConfigOptions {
    /**
     * List of did registrars that should be registered on the dids module. The registrar must
     * follow the {@link DidRegistrar} interface, and must be constructable. The registrar will be injected
     * into the `DidRegistrarService` and should be decorated with the `@injectable` decorator.
     *
     * If no registrars are provided, the default registrars will be used. The `PeerDidRegistrar` will ALWAYS be
     * registered, as it is needed for the connections and out of band module to function. Other did methods can be
     * disabled.
     *
     * @default [KeyDidRegistrar, SovDidRegistrar, PeerDidRegistrar]
     */
    registrars?: Constructor<DidRegistrar>[];
    /**
     * List of did resolvers that should be registered on the dids module. The resolver must
     * follow the {@link DidResolver} interface, and must be constructable. The resolver will be injected
     * into the `DidResolverService` and should be decorated with the `@injectable` decorator.
     *
     * If no resolvers are provided, the default resolvers will be used. The `PeerDidResolver` will ALWAYS be
     * registered, as it is needed for the connections and out of band module to function. Other did methods can be
     * disabled.
     *
     * @default [SovDidResolver, WebDidResolver, KeyDidResolver, PeerDidResolver]
     */
    resolvers?: Constructor<DidResolver>[];
}
export declare class DidsModuleConfig {
    private options;
    constructor(options?: DidsModuleConfigOptions);
    /** See {@link DidsModuleConfigOptions.registrars} */
    get registrars(): (typeof KeyDidRegistrar | typeof PeerDidRegistrar | typeof SovDidRegistrar | Constructor<DidRegistrar>)[];
    /** See {@link DidsModuleConfigOptions.resolvers} */
    get resolvers(): (typeof PeerDidResolver | typeof SovDidResolver | Constructor<DidResolver>)[];
}
