import type { FeatureQueryOptions } from '../../agent/models';
import type { DiscoverFeaturesService } from './services';
/**
 * Get the supported protocol versions based on the provided discover features services.
 */
export declare type ProtocolVersionType<DFSs extends DiscoverFeaturesService[]> = DFSs[number]['version'];
/**
 * Get the service map for usage in the discover features module. Will return a type mapping of protocol version to service.
 *
 * @example
 * ```
 * type DiscoverFeaturesServiceMap = ServiceMap<[V1DiscoverFeaturesService,V2DiscoverFeaturesService]>
 *
 * // equal to
 * type DiscoverFeaturesServiceMap = {
 *   v1: V1DiscoverFeatureService
 *   v2: V2DiscoverFeaturesService
 * }
 * ```
 */
export declare type ServiceMap<DFSs extends DiscoverFeaturesService[]> = {
    [DFS in DFSs[number] as DFS['version']]: DiscoverFeaturesService;
};
interface BaseOptions {
    connectionId: string;
}
export interface QueryFeaturesOptions<DFSs extends DiscoverFeaturesService[] = DiscoverFeaturesService[]> extends BaseOptions {
    protocolVersion: ProtocolVersionType<DFSs>;
    queries: FeatureQueryOptions[];
    awaitDisclosures?: boolean;
    awaitDisclosuresTimeoutMs?: number;
    comment?: string;
}
export interface DiscloseFeaturesOptions<DFSs extends DiscoverFeaturesService[] = DiscoverFeaturesService[]> extends BaseOptions {
    protocolVersion: ProtocolVersionType<DFSs>;
    disclosureQueries: FeatureQueryOptions[];
    threadId?: string;
}
export {};
